@@ -186,7 +186,8 @@ setMethod("glgm",
         paste(allVars, collapse=" "), ", data: ", 
         paste(names(data), collapse=" "))
 
-    cells = raster::trim(grid[['space']])
+#    cells = raster::trim(grid[['space']])
+    cells = grid[['space']]
     firstCell = values(cells)[1]
     cellDim = dim(cells)[1:2]
     # first cell = 2 * buffer^2 + ncolSmall * buffer + buffer
